Acknowledgements
================

The initial concept of this project was largely inspired in the `pdb-tools <https://github.com/haddocking/pdb-tools>`_ *one script one action* idea; here we then pushed this concept further.

The authors deeply thanks to `JoaoRodrigues <https://github.com/JoaoRodrigues>`_ for all the mentoring on MD and to `Susana Barrera-Vilarmau <https://viviendomochileros.com/2018/08/02/susana-barrera-vilarmau/>`_ for her intensive usage of the program during the very first development versions, discussion, feedback and suggestions on building a user-friendly interface.

Repository layout and Continuous Integration setup was initially provided by `cookiecutter-pylibrary <https://github.com/ionelmc/cookiecutter-pylibrary>`_, with final personalized modifications by the authors.
